# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# CURRENCY
class CurrencySerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency'
        model = models.Currency
        fields = '__all__'


class CurrencyListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_list'
        model = models.Currency
        fields = '__all__'


class CurrencyRetrieveSerializer(ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_retrieve'
        model = models.Currency
        fields = '__all__'


class CurrencyCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_create'
        model = models.Currency
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CurrencyRetrieveSerializer


class CurrencyUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_update'
        model = models.Currency
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CurrencyRetrieveSerializer


class CurrencyPartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_currency_currency_partial_update'
        model = models.Currency
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CurrencyRetrieveSerializer


class CurrencyEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_enable'
        model = models.Currency
        fields = ()
        response_serializer = CurrencyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class CurrencyDisableSerializer(ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_disable'
        model = models.Currency
        fields = ()
        response_serializer = CurrencyRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class CurrencyLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_light'
        model = models.Currency
        fields = ('code', 'status', 'status_display',)
